@@ -581,7 +581,7 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 {
 	GList *uris = NULL;
 	GdkScreen *screen;
-	GAppLaunchContext *ctx;
+	GdkAppLaunchContext *ctx;
 	gboolean result;
 	const char *uri;
 
@@ -596,14 +596,14 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 		uri = embedded->current_uri;
 	}
 
-	ctx = G_APP_LAUNCH_CONTEXT (gdk_app_launch_context_new ());
+	ctx = gdk_display_get_app_launch_context (gtk_widget_get_display (embedded->window));
 	screen = gtk_widget_get_screen (embedded->window);
-	gdk_app_launch_context_set_screen (GDK_APP_LAUNCH_CONTEXT (ctx), screen);
+	gdk_app_launch_context_set_screen (ctx, screen);
 
-	gdk_app_launch_context_set_timestamp (GDK_APP_LAUNCH_CONTEXT (ctx), user_time);
-	gdk_app_launch_context_set_icon (GDK_APP_LAUNCH_CONTEXT (ctx), g_app_info_get_icon (embedded->app));
+	gdk_app_launch_context_set_timestamp (ctx, user_time);
+	gdk_app_launch_context_set_icon (ctx, g_app_info_get_icon (embedded->app));
 
-	result = g_app_info_launch_uris (embedded->app, uris, ctx, NULL);
+	result = g_app_info_launch_uris (embedded->app, uris, G_APP_LAUNCH_CONTEXT (ctx), NULL);
 
 	g_list_free (uris);
 
